API Documentation
=================

Comprehensive reference material for every public API exposed by
:app:`Pyramid` is available within this chapter.  The API
documentation is organized alphabetically by module name.

.. toctree::
   :maxdepth: 1

   api/authorization
   api/authentication
   api/chameleon_text
   api/chameleon_zpt
   api/config
   api/events
   api/exceptions
   api/httpexceptions
   api/i18n
   api/interfaces
   api/location
   api/paster
   api/registry
   api/renderers
   api/request
   api/response
   api/scripting
   api/security
   api/session
   api/settings
   api/testing
   api/threadlocal
   api/traversal
   api/url
   api/view
   api/wsgi

